Class: AsposeWordsCloud::ApiClient

Inherits:
Object
  • Object
show all
Defined in:
lib/aspose_words_cloud/api_client.rb

Overview

api client is mainly responsible for making the HTTP call to the API backend.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(config = Configuration.default) ⇒ ApiClient

Initializes the ApiClient

Parameters:

  • config (Hash) (defaults to: Configuration.default)

    a customizable set of options

Options Hash (config):

  • Configuration (Configuration)

    for initializing the object, default to Configuration.default



54
55
56
57
58
59
60
61
# File 'lib/aspose_words_cloud/api_client.rb', line 54

def initialize(config = Configuration.default)
  @config = config
  @default_headers = {
    'Content-Type' => "application/json",
    'x-aspose-client' => "ruby sdk",
    'x-aspose-client-version' => AsposeWordsCloud::VERSION.to_s
  }
end

Instance Attribute Details

#configObject

The Configuration object holding settings to be used in the API client.



45
46
47
# File 'lib/aspose_words_cloud/api_client.rb', line 45

def config
  @config
end

#default_headersHash

Defines the headers to be used in HTTP requests of all API calls by default.

Returns:

  • (Hash)


50
51
52
# File 'lib/aspose_words_cloud/api_client.rb', line 50

def default_headers
  @default_headers
end

Class Method Details

.defaultObject



63
64
65
# File 'lib/aspose_words_cloud/api_client.rb', line 63

def self.default
  @@default ||= ApiClient.new
end

Instance Method Details

#add_param_to_query(url, param_name, param_value) ⇒ Object

Append query parameter to url

Parameters:

  • url (String)

    current url

  • param_name (String)

    query parameter name

  • param_value (String)

    query parameter value



575
576
577
578
579
580
581
582
583
584
585
# File 'lib/aspose_words_cloud/api_client.rb', line 575

def add_param_to_query(url, param_name, param_value)
  uri = URI(url)
  if param_name == 'password' && !param_value.empty?
    params = URI.decode_www_form(uri.query || "") << ['encryptedPassword', self.config.encryptor.encrypt(param_value)]
  else
    params = URI.decode_www_form(uri.query || "") << [param_name, param_value]
  end

  uri.query = URI.encode_www_form(params)
  uri.to_s
end

#build_collection_param(param, collection_format) ⇒ Object

Build parameter value according to the given collection format.

Parameters:

  • collection_format (String)

    one of :csv, :ssv, :tsv, :pipes and :multi



661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
# File 'lib/aspose_words_cloud/api_client.rb', line 661

def build_collection_param(param, collection_format)
  case collection_format
  when :csv
    param.join(',')
  when :ssv
    param.join(' ')
  when :tsv
    param.join("\t")
  when :pipes
    param.join('|')
  when :multi
    # return the array directly as faraday will handle it as expected
    param
  else
    raise "unknown collection format: #{collection_format.inspect}"
  end
end

#build_request(http_method, path, opts = {}) ⇒ Faraday::Response

Builds the HTTP request

Parameters:

  • http_method (String)

    HTTP method/verb (e.g. POST)

  • path (String)

    URL path (e.g. /account/new)

  • opts (Hash) (defaults to: {})

    a customizable set of options

Options Hash (opts):

  • :header_params (Hash)

    Header parameters

  • :query_params (Hash)

    Query parameters

  • :body (Object)

    HTTP body (JSON/XML)

Returns:

  • (Faraday::Response)

    A Faraday Response



119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
# File 'lib/aspose_words_cloud/api_client.rb', line 119

def build_request(http_method, path, opts = {})
  url = build_request_url(path)
  http_method = http_method.to_sym.downcase

  header_params = @default_headers.merge(opts[:header_params] || {})
  query_params = opts[:query_params] || {}
  update_params_for_auth! header_params, query_params, ["JWT"]
  body = opts[:body] if opts[:body] || nil?

  req_opts = {
    :method => http_method,
    :headers => header_params,
    :params => query_params,
    :body => body
  }

  if [:post, :patch, :put, :delete].include?(http_method)
    if @config.debugging
      @config.logger.debug "HTTP request body param ~BEGIN~\n#{req_body}\n~END~\n"
    end
  end

  conn = Faraday.new url, { :params => query_params, :headers => header_params, request: { timeout: @config.timeout }} do |f|
  f.request :multipart
  f.request :url_encoded
  f.adapter Faraday.default_adapter
  end

  case http_method
  when :post
    return conn.post url, req_opts[:body]
  when :put
    return conn.put url, req_opts[:body]
  when :get
    return conn.get url, req_opts[:body]
  else
    conn.delete url do |c|
      c.body = req_opts[:body]
    end
  end
end

#build_request_body(header_params, form_params, files_references) ⇒ String

Builds the HTTP request body

Parameters:

  • header_params (Hash)

    Header parameters

  • form_params (Hash)

    Query parameters

  • body (Object)

    HTTP body (JSON/XML)

Returns:

  • (String)

    HTTP body data in the form of string



465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
# File 'lib/aspose_words_cloud/api_client.rb', line 465

def build_request_body(header_params, form_params, files_references)
  # http form
  files_references.each do |file_reference|
    if !file_reference.password.nil?
        file_reference.encryptedPassword = self.config.encryptor.encrypt(file_reference.password)
        file_reference.password = nil
    end
    if file_reference.source == 'Request'
        form_params.push({:'Name' => file_reference.reference, :'Data' => file_reference.content, :'MimeType' =>'application/octet-stream'})
    end
  end

  if form_params.length() == 0
    data = nil
  elsif form_params.length() == 1
    form_param = form_params[0]
    value = form_param[:'Data']
    case value
    when ::File, ::Tempfile
      data = File.open(value.path, 'rb') { |f| f.read }
    when ::Array, nil, Faraday::ParamPart
      data = value
    else
      data = value.to_s
    end
    header_params['Content-Type'] = form_param[:'MimeType']
  else
    data = {}
    form_params.each do |form_param|
      key = form_param[:'Name']
      value = form_param[:'Data']
      mimeType = form_param[:'MimeType']
      case value
      when ::File, ::Tempfile
        data[key] = Faraday::FilePart.new(value.path, mimeType)
      when ::Array, nil, Faraday::ParamPart
        data[key] = value
      else
        data[key] = Faraday::ParamPart.new(value.to_s, mimeType)
      end
    end
  end

  data
end

#build_request_body_batch(header_params, form_params, files_references) ⇒ String

Builds the HTTP request body

Parameters:

  • header_params (Hash)

    Header parameters

  • form_params (Hash)

    Query parameters

  • body (Object)

    HTTP body (JSON/XML)

Returns:

  • (String)

    HTTP body data in the form of string



517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
# File 'lib/aspose_words_cloud/api_client.rb', line 517

def build_request_body_batch(header_params, form_params, files_references)
  files_references.each do |file_reference|
    if !file_reference.password.nil?
        file_reference.encryptedPassword = self.config.encryptor.encrypt(file_reference.password)
        file_reference.password = nil
    end
    if file_reference.source == 'Request'
        form_params.push({:'Name' => file_reference.reference, :'Data' => file_reference.content, :'MimeType' =>'application/octet-stream'})
    end
  end

  if form_params.length() == 0
    data = ''
  elsif form_params.length() == 1
    form_param = form_params[0]
    key = form_param[:'Name']
    value = form_param[:'Data']
    case value
    when ::File, ::Tempfile
      data = File.open(value.path, 'rb') { |f| f.read }
    when ::Array, nil, Faraday::ParamPart
      data = value
    else
      data = value.to_s
    end
    header_params['Content-Type'] = form_param[:'MimeType']
  else
    boundary = SecureRandom.uuid
    data = ""
    form_params.each do |form_param|
      key = form_param[:'Name']
      value = form_param[:'Data']
      mimeType = form_param[:'MimeType']
      data.concat(("--" + boundary + "\r\n").force_encoding('UTF-8'))
      data.concat(("Content-Type: " + mimeType + "\r\n").force_encoding('UTF-8'))
      data.concat(("Content-Disposition: form-data; name=\"" + key + "\"\r\n\r\n").force_encoding('UTF-8'))
      case value
      when ::File, ::Tempfile
        data.concat(File.open(value.path, 'rb') { |f| f.read })
      when ::Array, nil, Faraday::ParamPart
        data.concat(value)
      else
        data.concat(value.to_s)
      end
      data.concat(("\r\n").force_encoding('UTF-8'))
    end
    data.concat(("--" + boundary + "--").force_encoding('UTF-8'))
    header_params['Content-Type'] = 'multipart/form-data; boundary="' + boundary + '"';
  end

  data
end

#build_request_url(path) ⇒ Object



453
454
455
456
457
# File 'lib/aspose_words_cloud/api_client.rb', line 453

def build_request_url(path)
  # remove empty path parameter artifacts
  path = path.gsub(/\/+/, '/')
  return @config.getFullUrl(path, path == "/v4.0/words/connect/token")
end

#call_api(http_method, path, opts = {}) ⇒ Array<(Object, Fixnum, Hash)>

Call an API with given options.

Returns:

  • (Array<(Object, Fixnum, Hash)>)

    an array of 3 elements: the data deserialized from response body (could be nil), response status code and response headers.



71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
# File 'lib/aspose_words_cloud/api_client.rb', line 71

def call_api(http_method, path, opts = {})
  if @config.client_data['ClientId'].nil? || @config.client_data['ClientId'] == ''
    raise "ClientId could not be an empty string."
  end

  if @config.client_data['ClientSecret'].nil? || @config.client_data['ClientSecret'] == ''
    raise "ClientSecret could not be an empty string."
  end

  response = build_request(http_method, path, opts)
  if @config.debugging
    @config.logger.debug "'HTTP' response body '~BEGIN~'\n #{response.body}\n'~END~'\n"
  end

  unless response.success?
    if response.status == 0
      # Errors from libcurl will be made visible here
      raise ApiError.new(:code => 0,
                        :message => response.reason_phrase)
    else
      raise ApiError.new(:code => response.status,
                        :response_headers => response.headers,
                        :response_body => response.body),
           response.reason_phrase
    end
  end

  if opts[:multipart_response] == true
    data = deserialize_multipart(response.body, response.headers)
  elsif opts[:batch] == true
    data = deserialize_batch(response, opts[:request_map])
  elsif opts[:return_raw] == true
    data = response.body
  else
    data = deserialize(response.body, response.headers, opts[:return_type]) if opts[:return_type]
  end

  [data, response.status, response.headers]
end

#convert_to_type(data, return_type) ⇒ Mixed

Convert data to the given return type.

Parameters:

  • data (Object)

    Data to be converted

  • return_type (String)

    Return type

Returns:

  • (Mixed)

    Data in a particular type



402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
# File 'lib/aspose_words_cloud/api_client.rb', line 402

def convert_to_type(data, return_type)
  return nil if data.nil?
  case return_type
  when 'String'
    data.to_s
  when 'Integer'
    data.to_i
  when 'Float'
    data.to_f
  when 'BOOLEAN'
    data == true
  when 'DateTime'
    # parse date time (expecting ISO 8601 format)
    DateTime.parse data
  when 'Date'
    # parse date time (expecting ISO 8601 format)
    Date.parse data
  when 'Object'
    # generic object (usually a Hash), return directly
    data
  when /\AArray<(.+)>\z/
    # e.g. Array<Pet>
    sub_type = $1
    data.map {|item| convert_to_type(item, sub_type) }
  when /\AHash\<String, (.+)\>\z/
    # e.g. Hash<String, Integer>
    sub_type = $1
    {}.tap do |hash|
      data.each {|k, v| hash[k] = convert_to_type(v, sub_type) }
    end
  else
    # models, e.g. Pet
    if data[:'$type']
      return_type = data[:'$type'][0..-4]
    end

    AsposeWordsCloud.const_get(return_type).new.tap do |model|
      model.build_from_hash data
    end
  end
end

#custom_strip(string, chars) ⇒ Object



173
174
175
176
# File 'lib/aspose_words_cloud/api_client.rb', line 173

def custom_strip(string, chars)
  chars = Regexp.escape(chars)
  string.gsub(/\A[#{chars}]+|[#{chars}]+\z/, "")
end

#deserialize(body, headers, return_type) ⇒ Object

Deserialize the response to the given return type.

Parameters:

  • response (String)

    HTTP response

  • return_type (String)

    some examples: “User”, “Array”, “Hash



243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
# File 'lib/aspose_words_cloud/api_client.rb', line 243

def deserialize(body, headers, return_type)
  # handle file downloading - return the File instance processed in request callbacks
  # note that response body is empty when the file is written in chunks in request on_body callback
  return body if return_type == 'File'

  return parse_files_collection(body, headers) if return_type == 'FILES_COLLECTION'

  return nil if body.nil? || body.empty?

  # return response body directly for String return type
  return body if return_type == 'String'

  begin
    data = JSON.parse("[#{body}]", :symbolize_names => true)[0]
  rescue JSON::ParserError => e
    if %w[String Date DateTime].include?(return_type)
      data = body
    else
      raise e
    end
  end

  convert_to_type data, return_type
end

#deserialize_batch(response, request_map) ⇒ Object

Deserialize batch



352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
# File 'lib/aspose_words_cloud/api_client.rb', line 352

def deserialize_batch(response, request_map)
  result = { errors: [], parts: [] }
  def result.part(name)
    hash = self[:parts].detect { |h| h[:part].name == name }
    [hash[:part], hash[:body].join]
  end
  responses_data = []
  content_type = response.headers['content-type']
  reader = MultipartParser::Reader.new(MultipartParser::Reader::extract_boundary_value(content_type))
  reader.on_part do |part|
    result[:parts] << thispart = {
      part: part,
      body: []
    }
    part.on_data do |chunk|
      thispart[:body] << chunk
    end
  end
  reader.on_error do |msg|
    result[:errors] << msg
  end
  reader.write response.body
  reader.ended? or raise Exception, 'Truncated multipart message'

  separator = "\r\n\r\n"
  result[:parts].each do |part|
    part[:body] = part[:body].join("")
    part_body = part[:body]
    data_index = part_body.index(separator)
    if data_index != nil
      header_data = part_body[0..data_index]
      body_data = part_body[data_index+separator.length, part_body.length]
      part[:headers] = header_data
      part[:body] = body_data
    end
  end

  result[:parts].each_with_index do |response_data, index|
    req_id = response_data[:part].headers['requestid']
    batch_request = request_map[req_id]
    return_type = batch_request.request.get_response_type
    responses_data.push(deserialize(response_data[:body], response_data[:part].headers, return_type))
  end
  responses_data
end

#deserialize_http_response_part(request, part_data) ⇒ Object

Raises:



317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
# File 'lib/aspose_words_cloud/api_client.rb', line 317

def deserialize_http_response_part(request, part_data)
  status_line_index = part_data.index("\r\n")
  raise ApiError.new(code: 400, message: 'Failed to parse HTTP response part.', response_headers: {}, response_body: '') if status_line_index.nil?

  status_line = part_data[0...status_line_index]
  status_line_parts = status_line.split(' ', 3)
  if status_line_parts.length < 3 || !status_line_parts[0].start_with?('HTTP/')
    raise ApiError.new(code: 400, message: 'Failed to parse HTTP response part.', response_headers: {}, response_body: '')
  end

  status_code = status_line_parts[1].to_i
  headers_end_index = part_data.index("\r\n\r\n")
  response_headers = {}
  response_body = ''

  if headers_end_index.nil?
    response_body = part_data[(status_line_index + 2)..-1] || ''
  else
    header_lines = part_data[(status_line_index + 2)...headers_end_index].split("\r\n")
    header_lines.each do |header_line|
      next unless header_line.include?(':')
      key, value = header_line.split(':', 2)
      response_headers[key.strip.downcase] = value.strip
    end
    response_body = part_data[(headers_end_index + 4)..-1] || ''
  end

  if status_code < 200 || status_code >= 300
    raise ApiError.new(code: status_code, message: response_body, response_headers: response_headers, response_body: response_body)
  end

  request.deserialize_response(self, response_body, response_headers)
end

#deserialize_job_info_part(part) ⇒ Object



313
314
315
# File 'lib/aspose_words_cloud/api_client.rb', line 313

def deserialize_job_info_part(part)
  deserialize(part[:data], part[:headers], 'JobInfo')
end

#deserialize_multipart(body, headers) ⇒ Object

Deserialize multipart the response to the given return type.

Parameters:

  • response (Response)

    HTTP response



271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
# File 'lib/aspose_words_cloud/api_client.rb', line 271

def deserialize_multipart(body, headers)
  parts={}
  content_type = headers['content-type']
  reader = MultipartParser::Reader.new(MultipartParser::Reader::extract_boundary_value(content_type))

  reader.on_part do |part|
    pn = extract_partname_from_headers(part.headers)
    part.on_data do |partial_data|
      if parts[pn].nil?
        parts[pn] = { data: partial_data, headers: part.headers }
      else
        parts[pn][:data] = [parts[pn][:data]] if parts[pn][:data].kind_of?(Array)
        parts[pn][:data] << partial_data
      end
    end
  end

  reader.write body
  reader.ended? or raise Exception, 'Truncated multipart message'

  parts
end

#deserialize_multipart_array(body, headers) ⇒ Object



294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
# File 'lib/aspose_words_cloud/api_client.rb', line 294

def deserialize_multipart_array(body, headers)
  parts = []
  content_type = headers['content-type']
  reader = MultipartParser::Reader.new(MultipartParser::Reader::extract_boundary_value(content_type))

  reader.on_part do |part|
    part_data = { data: "", headers: part.headers }
    parts << part_data
    part.on_data do |partial_data|
      part_data[:data] << partial_data
    end
  end

  reader.write body
  reader.ended? or raise Exception, 'Truncated multipart message'

  parts
end

#extract_filename_from_headers(headers) ⇒ Object



178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
# File 'lib/aspose_words_cloud/api_client.rb', line 178

def extract_filename_from_headers(headers)
  filename = 'default'
  if headers.key?('content-disposition')
    disposition = headers['content-disposition']
    parts = disposition.split(';')
    for part in parts
      part2 = custom_strip(part, ' ')
      subparts = part2.split('=')
      if subparts.length() == 2 && subparts[0] == 'filename'
        filename = custom_strip(subparts[1], ' \"')
      end
    end
  end

  filename
end

#extract_partname_from_headers(headers) ⇒ Object



195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
# File 'lib/aspose_words_cloud/api_client.rb', line 195

def extract_partname_from_headers(headers)
  filename = 'default'
  if headers.key?('content-disposition')
    disposition = headers['content-disposition']
    parts = disposition.split(';')
    for part in parts
      part2 = custom_strip(part, ' ')
      subparts = part2.split('=')
      if subparts.length() == 2 && subparts[0] == 'name'
        filename = custom_strip(subparts[1], ' \"')
      end
    end
  end

  filename
end

#json_mime?(mime) ⇒ Boolean

Check if the given MIME is a JSON MIME. JSON MIME examples:

application/json
application/json; charset=UTF8
APPLICATION/JSON
*/*

Parameters:

  • mime (String)

    MIME

Returns:

  • (Boolean)

    True if the MIME is application/json



169
170
171
# File 'lib/aspose_words_cloud/api_client.rb', line 169

def json_mime?(mime)
   (mime == "*/*") || !(mime =~ /Application\/.*json(?!p)(;.*)?/i).nil?
end

#object_to_hash(obj) ⇒ String

Convert object(non-array) to hash.

Parameters:

  • obj (Object)

    object to be converted into JSON string

Returns:

  • (String)

    JSON string representation of the object



651
652
653
654
655
656
657
# File 'lib/aspose_words_cloud/api_client.rb', line 651

def object_to_hash(obj)
  if obj.respond_to?(:to_hash)
    obj.to_hash
  else
    obj
  end
end

#object_to_http_body(model) ⇒ String

Convert object (array, hash, object, etc) to JSON string.

Parameters:

  • model (Object)

    object to be converted into JSON string

Returns:

  • (String)

    JSON string representation of the object



636
637
638
639
640
641
642
643
644
645
646
# File 'lib/aspose_words_cloud/api_client.rb', line 636

def object_to_http_body(model)
  return '"' + model + '"' if model.is_a?(String)
  return model if model.nil? 
  local_body = nil
  if model.is_a?(Array)
    local_body = model.map { |m| object_to_hash(m) }
  else
    local_body = object_to_hash(model)
  end
  local_body.to_json
end

#parse_files_collection(data, headers) ⇒ Object

Deserialize files collection.



213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
# File 'lib/aspose_words_cloud/api_client.rb', line 213

def parse_files_collection(data, headers)
  result = {}
  if headers.key?("content-type") && headers['content-type'].start_with?('multipart/mixed')
    content_type = headers['content-type']
    reader = MultipartParser::Reader.new(MultipartParser::Reader::extract_boundary_value(content_type))
    reader.on_part do |part|
      pn = extract_filename_from_headers(part.headers)
      part.on_data do |partial_data|
        if result[pn].nil?
          result[pn] = partial_data
        else
          result[pn] = [result[pn]] if result[pn].kind_of?(Array)
          result[pn] << partial_data
        end
      end
    end

    reader.write data
    reader.ended? or raise Exception, 'Truncated multipart message'
  else
    result[extract_filename_from_headers(headers)] = data
  end

  result
end

#sanitize_filename(filename) ⇒ String

Sanitize filename by removing path. e.g. ../../sun.gif becomes sun.gif

Parameters:

  • filename (String)

    the filename to be sanitized

Returns:

  • (String)

    the sanitized filename



449
450
451
# File 'lib/aspose_words_cloud/api_client.rb', line 449

def sanitize_filename(filename)
  filename.gsub(/.*[\/\\]/, '')
end

#select_header_accept(accepts) ⇒ String

Return Accept header based on an array of accepts provided.

Parameters:

  • accepts (Array)

    array for Accept

Returns:

  • (String)

    the Accept header (e.g. application/json)



615
616
617
618
619
620
# File 'lib/aspose_words_cloud/api_client.rb', line 615

def select_header_accept(accepts)
  return nil if accepts.nil? || accepts.empty?
  # use JSON when present, otherwise use all of the provided
  json_accept = accepts.find { |s| json_mime?(s) }
  return json_accept || accepts.join(',')
end

#select_header_content_type(content_types) ⇒ String

Return Content-Type header based on an array of content types provided.

Parameters:

  • content_types (Array)

    array for Content-Type

Returns:

  • (String)

    the Content-Type header (e.g. application/json)



625
626
627
628
629
630
631
# File 'lib/aspose_words_cloud/api_client.rb', line 625

def select_header_content_type(content_types)
  # use application/json by default
  return 'application/json' if content_types.nil? || content_types.empty?
  # use JSON when present, otherwise use the first one
  json_content_type = content_types.find { |s| json_mime?(s) }
  return json_content_type || content_types.first
end

#update_params_for_auth!(header_params, query_params, auth_names) ⇒ Object

Update hearder and query params based on authentication settings.

Parameters:

  • header_params (Hash)

    Header parameters

  • query_params (Hash)

    Query parameters

  • auth_names (String)

    Authentication scheme name



592
593
594
595
596
597
598
599
600
601
602
# File 'lib/aspose_words_cloud/api_client.rb', line 592

def update_params_for_auth!(header_params, query_params, auth_names)
  Array(auth_names).each do |auth_name|
    auth_setting = @config.auth_settings[auth_name]
    next unless auth_setting
    case auth_setting[:in]
    when 'header' then header_params[auth_setting[:key]] = auth_setting[:value]
    when 'query'  then query_params[auth_setting[:key]] = auth_setting[:value]
    else raise ArgumentError, 'Authentication token must be in `query` of `header`'
    end
  end
end

#user_agent=(user_agent) ⇒ Object

Sets user agent in HTTP header

Parameters:

  • user_agent (String)

    User agent (e.g. swagger-codegen/ruby/1.0.0)



607
608
609
610
# File 'lib/aspose_words_cloud/api_client.rb', line 607

def user_agent=(user_agent)
  @user_agent = user_agent
  @default_headers['User-Agent'] = @user_agent
end