Class: AsposeWordsCloud::DeleteParagraphTabStopOnlineRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/aspose_words_cloud/models/requests/delete_paragraph_tab_stop_online_request.rb

Overview

Request model for delete_paragraph_tab_stop_online operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(document, position, index, node_path = nil, load_encoding = nil, password = nil, dest_file_name = nil) ⇒ DeleteParagraphTabStopOnlineRequest

Initializes a new instance.



63
64
65
66
67
68
69
70
71
# File 'lib/aspose_words_cloud/models/requests/delete_paragraph_tab_stop_online_request.rb', line 63

def initialize(document, position, index, node_path = nil, load_encoding = nil, password = nil, dest_file_name = nil)
  self.document = document
  self.position = position
  self.index = index
  self.node_path = node_path
  self.load_encoding = load_encoding
  self.password = password
  self.dest_file_name = dest_file_name
end

Instance Attribute Details

#dest_file_nameObject

Result path of the document after the operation. If this parameter is omitted then result of the operation will be saved as the source document.



51
52
53
# File 'lib/aspose_words_cloud/models/requests/delete_paragraph_tab_stop_online_request.rb', line 51

def dest_file_name
  @dest_file_name
end

#documentObject

The document.



33
34
35
# File 'lib/aspose_words_cloud/models/requests/delete_paragraph_tab_stop_online_request.rb', line 33

def document
  @document
end

#indexObject

Object index.



39
40
41
# File 'lib/aspose_words_cloud/models/requests/delete_paragraph_tab_stop_online_request.rb', line 39

def index
  @index
end

#load_encodingObject

Encoding that will be used to load an HTML (or TXT) document if the encoding is not specified in HTML.



45
46
47
# File 'lib/aspose_words_cloud/models/requests/delete_paragraph_tab_stop_online_request.rb', line 45

def load_encoding
  @load_encoding
end

#node_pathObject

The path to the node in the document tree.



42
43
44
# File 'lib/aspose_words_cloud/models/requests/delete_paragraph_tab_stop_online_request.rb', line 42

def node_path
  @node_path
end

#passwordObject

Password for opening an encrypted document.



48
49
50
# File 'lib/aspose_words_cloud/models/requests/delete_paragraph_tab_stop_online_request.rb', line 48

def password
  @password
end

#positionObject

The position of a tab stop to remove.



36
37
38
# File 'lib/aspose_words_cloud/models/requests/delete_paragraph_tab_stop_online_request.rb', line 36

def position
  @position
end