Class: AsposeWordsCloud::DownloadFileRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/aspose_words_cloud/models/requests/download_file_request.rb

Overview

Request model for download_file operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(path:, storage_name: nil, version_id: nil) ⇒ DownloadFileRequest

Initializes a new instance.

Parameters:

  • path

    Path of the file including the file name and extension e.g. /folder1/file.ext.

  • storage_name (defaults to: nil)

    Storage name.

  • version_id (defaults to: nil)

    File version ID to download.



47
48
49
50
51
# File 'lib/aspose_words_cloud/models/requests/download_file_request.rb', line 47

def initialize(path:, storage_name: nil, version_id: nil)
  self.path = path
  self.storage_name = storage_name
  self.version_id = version_id
end

Instance Attribute Details

#pathObject

Path of the file including the file name and extension e.g. /folder1/file.ext.



33
34
35
# File 'lib/aspose_words_cloud/models/requests/download_file_request.rb', line 33

def path
  @path
end

#storage_nameObject

Storage name.



36
37
38
# File 'lib/aspose_words_cloud/models/requests/download_file_request.rb', line 36

def storage_name
  @storage_name
end

#version_idObject

File version ID to download.



39
40
41
# File 'lib/aspose_words_cloud/models/requests/download_file_request.rb', line 39

def version_id
  @version_id
end

Instance Method Details

#create_http_request(api_client) ⇒ Object

Raises:

  • (ArgumentError)


109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
# File 'lib/aspose_words_cloud/models/requests/download_file_request.rb', line 109

def create_http_request(api_client)
  # verify the required parameter 'path' is set
  raise ArgumentError, 'Missing the required parameter path when calling WordsApi.download_file' if api_client.config.client_side_validation && self.path.nil?

  # resource path
  local_var_path = '/words/storage/file/{path}'[1..-1]
  local_var_path = local_var_path.sub('{' + downcase_first_letter('Path') + '}', self.path.nil? ? '' : self.path.to_s)
  local_var_path = local_var_path.sub('//', '/')

  # query parameters
  query_params = {}
  query_params[downcase_first_letter('StorageName')] = self.storage_name unless self.storage_name.nil?
  query_params[downcase_first_letter('VersionId')] = self.version_id unless self.version_id.nil?

  # header parameters
  header_params = {}
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = api_client.select_header_content_type(['application/xml', 'application/json'])

  # form parameters
  form_params = []
  files_content = []
  body = api_client.build_request_body(header_params, form_params, files_content)
  {
    'method': :GET,
    'path': local_var_path,
    'header_params': header_params,
    'query_params': query_params,
    'body': body,
    'auth_names': ['JWT']
  }
end

#deserialize_response(api_client, body, headers) ⇒ Object



154
155
156
# File 'lib/aspose_words_cloud/models/requests/download_file_request.rb', line 154

def deserialize_response(api_client, body, headers)
  api_client.deserialize(body, headers, 'File')
end

#downcase_first_letter(str) ⇒ Object

Helper method to convert first letter to downcase



145
146
147
# File 'lib/aspose_words_cloud/models/requests/download_file_request.rb', line 145

def downcase_first_letter(str)
  str[0].downcase + str[1..-1]
end

#get_original_requestObject



53
54
55
# File 'lib/aspose_words_cloud/models/requests/download_file_request.rb', line 53

def get_original_request
  self
end

#get_response_typeObject

Get response type



150
151
152
# File 'lib/aspose_words_cloud/models/requests/download_file_request.rb', line 150

def get_response_type
  'File'
end

#to_batch_part(api_client, requestId, parentRequestId = nil) ⇒ Object

Creating batch part from request

Raises:

  • (ArgumentError)


58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
# File 'lib/aspose_words_cloud/models/requests/download_file_request.rb', line 58

def to_batch_part(api_client, requestId, parentRequestId = nil)
  # verify the required parameter 'path' is set
  raise ArgumentError, 'Missing the required parameter path when calling WordsApi.download_file' if api_client.config.client_side_validation && self.path.nil?

  # resource path
  local_var_path = '/words/storage/file/{path}'[7..-1]
  local_var_path = local_var_path.sub('{' + downcase_first_letter('Path') + '}', self.path.nil? ? '' : self.path.to_s)
  local_var_path = local_var_path.sub('//', '/')

  # query parameters
  query_params = {}
  query_params[downcase_first_letter('StorageName')] = self.storage_name unless self.storage_name.nil?
  query_params[downcase_first_letter('VersionId')] = self.version_id unless self.version_id.nil?

  if query_params
    query_params.each { |key, value| local_var_path = api_client.add_param_to_query(local_var_path, key, value) }
  end

  header_params = {}
  header_params['RequestId'] = requestId

  if parentRequestId != nil
    header_params['DependsOn'] = parentRequestId
  end

  # form parameters
  form_params = []
  files_content = []

  # http body (model)
  body = api_client.build_request_body_batch(header_params, form_params, files_content)
  part = ""
  part.concat("GET".force_encoding('UTF-8'))
  part.concat(" ".force_encoding('UTF-8'))
  part.concat(local_var_path.force_encoding('UTF-8'))
  part.concat(" \r\n".force_encoding('UTF-8'))

  header_params.each_pair {|key, value| part.concat(key.dup.force_encoding('UTF-8') , ": ".force_encoding('UTF-8'), value.dup.force_encoding('UTF-8'), "\r\n".force_encoding('UTF-8')) }
  part.concat("\r\n".force_encoding('UTF-8'))
  if body
    if body.is_a?(Hash)
      body.each do |key, value|
        part.concat(value, "\r\n")
      end
    else
      part.concat(body)
    end
  end
 part
end