Class: AsposeWordsCloud::ProtectDocumentRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/aspose_words_cloud/models/requests/protect_document_request.rb

Overview

Request model for protect_document operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(name, protection_request, folder = nil, storage = nil, load_encoding = nil, password = nil, dest_file_name = nil) ⇒ ProtectDocumentRequest

Initializes a new instance.



63
64
65
66
67
68
69
70
71
# File 'lib/aspose_words_cloud/models/requests/protect_document_request.rb', line 63

def initialize(name, protection_request, folder = nil, storage = nil, load_encoding = nil, password = nil, dest_file_name = nil)
  self.name = name
  self.protection_request = protection_request
  self.folder = folder
  self.storage = storage
  self.load_encoding = load_encoding
  self.password = password
  self.dest_file_name = dest_file_name
end

Instance Attribute Details

#dest_file_nameObject

Result path of the document after the operation. If this parameter is omitted then result of the operation will be saved as the source document.



51
52
53
# File 'lib/aspose_words_cloud/models/requests/protect_document_request.rb', line 51

def dest_file_name
  @dest_file_name
end

#folderObject

Original document folder.



39
40
41
# File 'lib/aspose_words_cloud/models/requests/protect_document_request.rb', line 39

def folder
  @folder
end

#load_encodingObject

Encoding that will be used to load an HTML (or TXT) document if the encoding is not specified in HTML.



45
46
47
# File 'lib/aspose_words_cloud/models/requests/protect_document_request.rb', line 45

def load_encoding
  @load_encoding
end

#nameObject

The filename of the input document.



33
34
35
# File 'lib/aspose_words_cloud/models/requests/protect_document_request.rb', line 33

def name
  @name
end

#passwordObject

Password for opening an encrypted document.



48
49
50
# File 'lib/aspose_words_cloud/models/requests/protect_document_request.rb', line 48

def password
  @password
end

#protection_requestObject

Protection request.



36
37
38
# File 'lib/aspose_words_cloud/models/requests/protect_document_request.rb', line 36

def protection_request
  @protection_request
end

#storageObject

Original document storage.



42
43
44
# File 'lib/aspose_words_cloud/models/requests/protect_document_request.rb', line 42

def storage
  @storage
end